// prototype.h
// $Id: prototype.h,v 1.4 2007/11/13 11:45:17 sendan Exp $
// masashi shimakura

/* --- sitar.c --- */
int safe_exit(char *);
int check_alget(char *);
int life_put(void);
int start_neg(void);
int setup_conf(void);
int get_statfile(char *);
int get_configfile(char *, char *);
int get_alget(char *, char *);
int my_chmem(char *, char *);
char * check_strtol(char *);
int life_pthread(void);
void * scan_block(int);
int sitar_scan(void);
int sitar_cron(void);


/* --- confset.c --- */
int conf_set(char *);
int set_data(void);

int setup_check(void);
int print_conf(void);
int path_check(char *);

/* --- fifo.c --- */
int fifo_make(char *, int);

/* --- opt.c --- */
int optin(int, char *[]);

/* --- malloc_set --- */
int scan_malloc_set(private_data_t *);
int scan_malloc_free(private_data_t *);
int m_exit(int);


int swap_malloc_set(void);
int swap_malloc_free(void);

int malloc_set(void);
int malloc_set_free(void);
int malloc_set2(void);
int malloc_set2_free(void);
int safree(int);
int sacalloc(int);
int satmpfree(void);
int satmpcalloc(void);

/* --- scan_port.c --- */
int scan_port(struct scan_buf *);

/* --- scan_snmp.c --- */
int scan_snmp(struct scan_buf *);

/* --- scan_comand.c --- */
int scan_comand(private_data_t *);

/* --- filestat.c --- */
char * stat_check(char *, char *, int, int *);

/* --- times.c --- */
int hloop(int, int, int, int, int, int);
int floop(int, int, int, int, int,    int, int, int, int, int);

/* --- time_format.c --- */
int time_format(char *, int *, int *, int *, int *, int *);

/* --- swap_char.c --- */
int swap_char(char *);



